@@ -4,7 +4,7 @@ use strict;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = 0.08;
+$VERSION = 0.09;
 
 use DateTime;
 use DateTime::Format::Epoch;
@@ -35,13 +35,16 @@ DateTime::Format::Epoch::ActiveDirectory -  Active Directory epoch seconds
 
   use DateTime::Format::Epoch::ActiveDirectory;
 
-  my $formatter = DateTime::Format::Epoch::ActiveDirectory->new();
+  my $dt = DateTime::Format::Epoch::ActiveDirectory
+                ->parse_datetime( 1051488000 );
 
-  my $dt2 = $formatter->parse_datetime( 1051488000 );
-
-  $formatter->format_datetime($dt2);
+  DateTime::Format::Epoch::ActiveDirectory->format_datetime($dt);
    # 1051488000
 
+  my $formatter = DateTime::Format::Epoch::ActiveDirectory->new();
+  my $dt2 = $formatter->parse_datetime( 1051488000 );
+  $formatter->format_datetime($dt2);
+
 =head1 DESCRIPTION
 
 This module can convert a DateTime object (or any object that can be
